% 6G6Z3012 Group Theory
% Options talk by Dr Killian O'Brien
% MMU, February 2018

# The unit

* Taught by Dr Killian O'Brien + Dr Jan Foniok
* 2 hours lecture + 1 hour lab/tutorial per week
* Coursework problems (40%), Examination (60%)
* A unit that allows you to continue your study of pure mathematics
* Excellent free open-source textbook, [*Abstract Algebra*](http://abstract.pugetsound.edu/), by Tom Judson


# The unit

* A thorough introduction to a substantial area of pure mathematics that has strong connections to areas of geometry, combinatorics, graph theory, ... .
* Definitely suited to students who like problem solving and the unit will develop your skills in this area.
* We will use the Sage mathematics system to aid our investigations. You will also get an introduction to the Python programming language.  ([SageMath](http://www.sagemath.org), [CoCalc](https://cocalc.com), [sagecell.sagemath.org](https://sagecell.sagemath.org))

# The unit gives

* An appreciation for the many aspects of group theory and its connections to other areas of mathematics.
* Development of your problem solving and abstract thinking skills.
* Exposure to SageMath mathematical software, aimed at pure mathematics teaching and research.
* SageMath uses the Python programming language which is widely used in many areas of computing.

# What is a group?

A set of mathematical objects with a mathematically meaningful operation applied amongst them that is *well behaved*, will be a group. It's a very broad concept and present in many areas of mathematics.

# More formally

A set $G$ with a binary operation $\star$ satisfying

* $G$ is a closed system under $\star$, i.e. $x \star y \in G$.
* $\star$ is associative on $G$, i.e. $x \star ( y \star z) = (x \star y) \star z$.
* $G$ contains an identity element, $e$, for $\star$, i.e.
$$x \star e = e \star x = x.$$
* $G$ contains inverse elements for $\star$, i.e. $x \star x^{-1} = e$.

# Syllabus topics

--------------------------

### Examples of groups:

* Symmetry groups of two and three-dimensional objects,
* the dihedral groups $D_n$,
* rotational symmetry groups of three-dimensional polyhedra.
* Permutation groups, the Symmetric groups $S_n$ and the Alternating groups $A_n$,
* Number based groups under arithmetic operations,
* the cyclic groups $\mathbb{Z}_n$,
* Groups of matrices

---------------------------------

$\Gamma^+(T)$ is the set of rotational symmetries of the tetrahedron.

<img height="400" src=./tetrahedrons.png>

----------------------------------

The symmetric group, $S_4$, is the group of all rearrangments, or *permutations*, of four objects.

<img height="400" src=./S4_Cayley.png>

------------------------------------

Group theory lends itself to visual thinking with beautiful mapping diagrams

<img height="400" src=./homomorphisms.png>

from Nathan Carter's *Visual Group Theory*, MAA

--------------------------

# Syllabus topics

# Classification problems:

* The grand enterprise of group theory is to discover and classify all the groups that there are.
* What classification problems can be posed?

# Lagrange's theorem:

* Restricts the possibilities for the sizes of subgroups.
* If $H$ is a subgroup of $G$ then $|H|$ divides $|G|$.

# Lagrange's theorem

<img height="400" src=./MAA.png>

A page from *Groups and Symmetry* by M. A. Armstrong.

------------

### The classification of finitely presented Abelian groups:

* All the possible structures of such groups are found and classified
* Can relate this to a type of matrix reduction algorithm on presentation matrices of such groups

-------------------------------

# Classification of groups of low order:

What about non-Abelian groups? Why we can't solve using matrix reduction? Investigation of groups of low order and enumeration and classification of all groups up to some suitable order.

------------------------------

# Sylow's theorems:

* Discussion of the converse to Lagrange's theorem:
* If $d$ divides $|G|$, does $G$ have a subgroup of size $d$?.
* Group actions, orbits, stabilizers. Self-action by conjugation.
* Sylow's theorems relating to powers of prime divisors of $|G|$.


# Wider interest material / applications

The unit allows us to access interesting general material on the following topics/applications.

# The classification of finite simple groups

The grand project. Status of the proof. Some history and biographical details of the completion of the project. The families in the classification. The sporadic groups. The Monster group and Monstrous Moonshine.

# The Monster group

* A group, $M$, with approx. $8 \times 10^{53}$ elements, that is *simple*, i.e. it has no *normal* subgroups.
* $M$ is (isomorphic to) a group of rotations of 196883-dimensional space.
* $M$ is (isomorphic to) a group of matrices generated by two particular binary $196882 \times 196882$ matrices.

-------------------------

### Algorithmic problems

The word problem. Computability. Alan Turing.

<img height="400" src=./turing.jpg>

---------------------------------

### Combinatorial enumeration and geometric classification problems

Counting number of distinguishable colourings of geometric objects. Classifying the symmetry types of two-dimensional wallpaper patterns. Classifying two and three-dimensional crystal structures (lattices).

-----------------------------------

The are exactly 17 different types of wallpaper, when classified according to their symmetries.

<img height="400" src=./wallpapers.png>

---------------------------------

# Galois theory

<img height="200" src=./Galois.jpeg>

* Life of Galois (1811 - 1832).
* Galois theory.
* Formulas for roots of polynomials.
* Construction problems with ruler and compass.

# SageMath

~~~~~{.python}
G=DihedralGroup(12)

HH = [H for H in G.subgroups() if not H.order()==1]

for H in HH:
    P = plot(H.cayley_graph(), vertex_labels=False)
    show(P)
~~~~~

The above code displays the *Cayley Graph* of every subgroup of $D_{12}$. See the results from SageMath in a [SageCell](https://sagecell.sagemath.org/?z=eJw9kLFqxDAQRHuD_2HgGruIwVcGXCUgfcB1IQTFXluCPa2RZA7_fSSfc1sO82Z2Vw2fztIUDKsg29r017auLlBwEckSlqJCZgRJJjnxhmH8VDyBZqbx1OJ-v1MKjmIxZ_LpWDY2Af31LbqJJqzC-yK-rupKawz40pglQMN5qC5uv0ddbFq4GV4SdCdhotC0w9B_l8iMnZtFSqXKcC7_B4ugSvoFt2yZhVkezi9HC4usWIPz6RlQXB9mZ9rzlWa1BSYz2lfcmfbaUOv3ukKeaOXR6G484J8Dbtr8tz_mQmmX&lang=sage) or on [CoCalc](https://cocalc.com/share/a3801a5c-c6a5-4856-9e32-b6a99a7d2600/options/groups18/cayleygraphs.sagews?viewer=share)







